@@ -3,8 +3,6 @@ from __future__ import annotations
 from .extension import SQLAlchemy
 
 
-__version__ = "1.4.47"
+__version__ = "2.0.0"
 
-__all__ = [
-    "SQLAlchemy",
-]
+__all__ = ["SQLAlchemy"]
